==> cas-service-metadata-0.0.84-sources.jar: com/xforceplus/ultraman/app/casservice/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.casservice.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2024-01-06
 */

public class PageMeta {
    public interface SalesOrgnizationAffiliateInfoPage {
        static String code() {
            return "salesOrgnizationAffiliateInfoPage";
        }
        static String name() {
            return "销售组织附属信息页面";
        }
    }
    public interface RetailerSupplierMappingConfigRule {
        static String code() {
            return "retailerSupplierMappingConfigRule";
        }
        static String name() {
            return "零售商供应商映射配置规则";
        }
    }
    public interface PopSalesArchivesForPosOrderPage {
        static String code() {
            return "popSalesArchivesForPosOrderPage";
        }
        static String name() {
            return "销售档案POS单选择页面";
        }
    }
    public interface SceneCodeAndSalesArchivesTypeMappingPage {
        static String code() {
            return "sceneCodeAndSalesArchivesTypeMappingPage";
        }
        static String name() {
            return "场景码销售档案分类关联关系";
        }
    }
    public interface POS门店搜索 {
        static String code() {
            return "POS门店搜索";
        }
        static String name() {
            return "posStoreSearch";
        }
    }
    public interface ConfigRuleTemplatePage {
        static String code() {
            return "configRuleTemplatePage";
        }
        static String name() {
            return "配置规则模板页面";
        }
    }
    public interface PopSalesArchivesPage {
        static String code() {
            return "popSalesArchivesPage";
        }
        static String name() {
            return "销售档案订单选择页面";
        }
    }
    public interface SalesArchivesPage {
        static String code() {
            return "salesArchivesPage";
        }
        static String name() {
            return "销售档案页面";
        }
    }
    public interface RetailerSupplierMappingPage {
        static String code() {
            return "retailerSupplierMappingPage";
        }
        static String name() {
            return "零售商供应商映射关系页面";
        }
    }
}

==> cas-service-metadata-0.0.161-sources.jar: com/xforceplus/ultraman/app/casservice/metadata/meta/PageMeta.java <==
package com.xforceplus.ultraman.app.casservice.metadata.meta;

/**
 * 页面元数据
 *
 * @author ultraman
 * @since 2024-01-30
 */

public class PageMeta {
    public interface PopSalesArchivesPageOrg {
        static String code() {
            return "popSalesArchivesPageOrg";
        }
        static String name() {
            return "销售档案订单选择页面分公司";
        }
    }
    public interface PopSalesArchivesPageShip {
        static String code() {
            return "popSalesArchivesPageShip";
        }
        static String name() {
            return "销售档案订单选择页面送达方";
        }
    }
    public interface SalesOrgnizationAffiliateInfoPage {
        static String code() {
            return "salesOrgnizationAffiliateInfoPage";
        }
        static String name() {
            return "销售组织附属信息页面";
        }
    }
    public interface SceneCodeAndSalesArchivesTypeMappingPage {
        static String code() {
            return "sceneCodeAndSalesArchivesTypeMappingPage";
        }
        static String name() {
            return "场景码销售档案分类关联关系";
        }
    }
    public interface POS门店搜索 {
        static String code() {
            return "POS门店搜索";
        }
        static String name() {
            return "posStoreSearch";
        }
    }
    public interface PopSalesArchivesForPosOrderPage {
        static String code() {
            return "popSalesArchivesForPosOrderPage";
        }
        static String name() {
            return "销售档案POS单选择页面";
        }
    }
    public interface PurchaseOrgs {
        static String code() {
            return "purchaseOrgs";
        }
        static String name() {
            return "卖场门店新客商";
        }
    }
    public interface PopSalesArchivesPageSold {
        static String code() {
            return "popSalesArchivesPageSold";
        }
        static String name() {
            return "销售档案订单选择页面售达方";
        }
    }
    public interface ConfigRuleTemplatePage {
        static String code() {
            return "configRuleTemplatePage";
        }
        static String name() {
            return "配置规则模板页面";
        }
    }
    public interface PopSalesArchivesPage {
        static String code() {
            return "popSalesArchivesPage";
        }
        static String name() {
            return "销售档案订单选择页面";
        }
    }
    public interface RetailerSupplierMappingConfigRule {
        static String code() {
            return "retailerSupplierMappingConfigRule";
        }
        static String name() {
            return "零售商供应商映射配置规则";
        }
    }
    public interface SalesArchivesPage {
        static String code() {
            return "salesArchivesPage";
        }
        static String name() {
            return "销售档案页面";
        }
    }
    public interface RetailerSupplierMappingPage {
        static String code() {
            return "retailerSupplierMappingPage";
        }
        static String name() {
            return "零售商供应商映射关系页面";
        }
    }
}
